"""Version and details for pyfaup"""

__description__ = "Python bindings for the faup library"
__url__ = "https://www.github.com/stricaud/faup"
__version__ = "1.1"
__author__ = "Sebastien Tricaud"
__author_email__ = "sebastien@honeynet.org"
__license__ = "MIT"
__maintainer__ = __author__
__maintainer_email__ = __author_email__
